#
# spec file for package mojo-parent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mojo-parent
Version:        82
Release:        1.3
Summary:        Codehaus MOJO parent project pom file
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://www.mojohaus.org/mojo-parent/
Source0:        https://github.com/mojohaus/%{name}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        http://www.apache.org/licenses/LICENSE-2.0.txt
BuildRequires:  javapackages-local
Requires:       mvn(org.junit:junit-bom:pom:)
BuildArch:      noarch

%description
Codehaus MOJO parent project pom file

%prep
%setup -q
# Not needed
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :spotless-maven-plugin

cp %{SOURCE1} .

%build

%install
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
install -pm 0644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom -a org.codehaus.mojo:mojo

%files -f .mfiles
%license LICENSE-2.0.txt

%changelog
* Wed Jun 12 2024 Fridrich Strba <fstrba@suse.com>
- Update to 82:
  * Potentially Breaking Changes
    + mojo.java.target should be set as "8", without "1."; it is
    now used for release options
    + spotless plugin must be executed by JDK 11 at least, use
    profile if needed
    + ossrh-snapshots repository was removed from parent; if needed
    please add in project where it is used
  * New features and improvements
    + Do not include tests code in JavaDocs
    + Remove SHA-512 checksum for source release artifact
    + Use only project version as tag for release
    + Add space before close empty elements in poms by spotless
    + Using Checkstyle together with Spotless
    + Introduce spotless for automatic code formatting
    + Introduce enforcer rule for minimal version of Java and Maven
    + Remove jxr from reporting
    + Remove taglist from reporting
    + Remove Surefire from reporting
    + Use new Plugin Tools report - maven-plugin-report-plugin
    + Remove PMD from reporting
    + Remove Checkstyle from reporting
    + Add sisu-maven-plugin
    + Introduce maven.version property - allow projects to override
    + Execute spotless by JDK 11 at least
    + Use release options for m-compiler-p with newer JDKs
    + Allow override of invoker.streamLogsOnFailures
    + Require Maven 3.9.x at least for releases
    + Add maven-wrapper-plugin to pluginManagement
    + Remove ossrh-snapshots repository from MojoHaus parent
    + Add build-helper-maven-plugin to pluginManagement
    + Require Maven 3.6.3+
    + Update palantirJavaFormat for spotless - JDK 21 compatible
    + Add dependencyManagement for maven-shade-plugin
    + Remove dead markmail.org from mailing lists
    + simplify life for using spotless (active per default),
    document property to de activate it
    + Drop recommendedJavaBuildVersion property
    + Format Markdown files with Spotless Plugin
  * Bug Fixes
    + Restore source release distribution in child projects
    + Rename property maven.version to mavenVersion
    + minimalMavenBuildVersion should not be overriding by
    mavenVersion
    + Use simple checkstyle rules since spotless is executed by
    default
    + Use old spotless version only for JDK < 11
    + Fix spotless configuration for markdown - exclude generated
    files
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 70:
  * Improvement checkstyle configuration
  * Add modello-maven-plugin to pluginManagement
  * Remove Google search box due to privacy
  * Put version for mrm-maven-plugin in property
  * Add streamLogsOnFailures to m-invoker-p
  * Add property for maven-fluido-skin version
  * Setup Apache Matomo analytics
  * Downgrade Checkstyle to 9.3. 10.x requires Java 11(ecfb1d1)
  * remove requirement to use ssh for github scm devCon
  * Require Maven 3.2.5
  * [#225] add SHA-512 hashes
  * Extract plugin version as variable so child pom can override if needed
  * remove issue-tracking as do not exists anymore
  * remove cim report as it do not exists anymore
* Fri Mar 25 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 60
  * Compatible with newer plugins
* Sun Mar 17 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of mojo-parent 40
